@@ -13,11 +13,13 @@
 
 //! A wrapped `crate::Message` with `JetStream` related methods.
 use super::context::Context;
-use crate::{error, header, Error};
+use crate::header::{IntoHeaderName, IntoHeaderValue};
+use crate::subject::ToSubject;
+use crate::{error, header, message, Error, HeaderValue};
 use crate::{subject::Subject, HeaderMap};
 use bytes::Bytes;
-use futures::future::TryFutureExt;
-use futures::StreamExt;
+use futures_util::future::TryFutureExt;
+use futures_util::StreamExt;
 use std::fmt::Display;
 use std::{mem, time::Duration};
 use time::format_description::well_known::Rfc3339;
@@ -33,6 +35,119 @@ pub struct StreamMessage {
     pub time: OffsetDateTime,
 }
 
+/// An outbound message to be published.
+/// Does not contain status or description which are valid only for inbound messages.
+pub struct OutboundMessage {
+    pub subject: Subject,
+    pub payload: Bytes,
+    pub headers: Option<HeaderMap>,
+}
+
+impl OutboundMessage {
+    pub fn new(subject: Subject, payload: Bytes, headers: Option<HeaderMap>) -> Self {
+        Self {
+            subject,
+            payload,
+            headers,
+        }
+    }
+}
+
+impl From<OutboundMessage> for message::OutboundMessage {
+    fn from(message: OutboundMessage) -> Self {
+        message::OutboundMessage {
+            subject: message.subject,
+            payload: message.payload,
+            headers: message.headers,
+            reply: None,
+        }
+    }
+}
+
+/// Used for building customized `publish` message.
+#[derive(Default, Clone, Debug)]
+pub struct PublishMessage {
+    pub(crate) payload: Bytes,
+    pub(crate) headers: Option<header::HeaderMap>,
+}
+impl PublishMessage {
+    /// Creates a new custom Publish struct to be used with.
+    pub fn build() -> Self {
+        Default::default()
+    }
+
+    /// Sets the payload for the message.
+    pub fn payload(mut self, payload: Bytes) -> Self {
+        self.payload = payload;
+        self
+    }
+    /// Adds headers to the message.
+    pub fn headers(mut self, headers: HeaderMap) -> Self {
+        self.headers = Some(headers);
+        self
+    }
+    /// A shorthand to add a single header.
+    pub fn header<N: IntoHeaderName, V: IntoHeaderValue>(mut self, name: N, value: V) -> Self {
+        self.headers
+            .get_or_insert(header::HeaderMap::new())
+            .insert(name, value);
+        self
+    }
+    /// Sets the `Nats-Msg-Id` header, that is used by stream deduplicate window.
+    pub fn message_id<T: AsRef<str>>(self, id: T) -> Self {
+        self.header(header::NATS_MESSAGE_ID, id.as_ref())
+    }
+    /// Sets expected last message ID.
+    /// It sets the `Nats-Expected-Last-Msg-Id` header with provided value.
+    pub fn expected_last_message_id<T: AsRef<str>>(self, last_message_id: T) -> Self {
+        self.header(
+            header::NATS_EXPECTED_LAST_MESSAGE_ID,
+            last_message_id.as_ref(),
+        )
+    }
+    /// Sets the last expected stream sequence.
+    /// It sets the `Nats-Expected-Last-Sequence` header with provided value.
+    pub fn expected_last_sequence(self, last_sequence: u64) -> Self {
+        self.header(
+            header::NATS_EXPECTED_LAST_SEQUENCE,
+            HeaderValue::from(last_sequence),
+        )
+    }
+    /// Sets the last expected stream sequence for a subject this message will be published to.
+    /// It sets the `Nats-Expected-Last-Subject-Sequence` header with provided value.
+    pub fn expected_last_subject_sequence(self, subject_sequence: u64) -> Self {
+        self.header(
+            header::NATS_EXPECTED_LAST_SUBJECT_SEQUENCE,
+            HeaderValue::from(subject_sequence),
+        )
+    }
+    /// Sets the expected stream name.
+    /// It sets the `Nats-Expected-Stream` header with provided value.
+    pub fn expected_stream<T: AsRef<str>>(self, stream: T) -> Self {
+        self.header(
+            header::NATS_EXPECTED_STREAM,
+            HeaderValue::from(stream.as_ref()),
+        )
+    }
+
+    #[cfg(feature = "server_2_11")]
+    /// Sets TTL for a single message.
+    /// It sets the `Nats-TTL` header with provided value.
+    pub fn ttl(self, ttl: Duration) -> Self {
+        self.header(header::NATS_MESSAGE_TTL, ttl.as_secs().to_string())
+    }
+
+    /// Creates an [crate::jetstream::message::OutboundMessage] that can be sent using
+    /// [crate::jetstream::context::traits::Publisher::publish_message].
+    pub fn outbound_message<S: ToSubject>(self, subject: S) -> OutboundMessage {
+        OutboundMessage {
+            subject: subject.to_subject(),
+            payload: self.payload,
+            headers: self.headers,
+        }
+    }
+}
+
 #[derive(Clone, Debug)]
 pub struct Message {
     pub message: crate::Message,
@@ -56,7 +171,7 @@ impl TryFrom<crate::Message> for StreamMessage {
                 seq.as_str().parse().map_err(|err| {
                     StreamMessageError::with_source(
                         StreamMessageErrorKind::ParseError,
-                        format!("could not parse sequence header: {}", err),
+                        format!("could not parse sequence header: {err}"),
                     )
                 })
             })?;
@@ -70,7 +185,7 @@ impl TryFrom<crate::Message> for StreamMessage {
                 OffsetDateTime::parse(time.as_str(), &Rfc3339).map_err(|err| {
                     StreamMessageError::with_source(
                         StreamMessageErrorKind::ParseError,
-                        format!("could not parse timestamp header: {}", err),
+                        format!("could not parse timestamp header: {err}"),
                     )
                 })
             })?;
@@ -150,7 +265,7 @@ impl Message {
     /// # #[tokio::main]
     /// # async fn main() -> Result<(), async_nats::Error> {
     /// use async_nats::jetstream::consumer::PullConsumer;
-    /// use futures::StreamExt;
+    /// use futures_util::StreamExt;
     /// let client = async_nats::connect("localhost:4222").await?;
     /// let jetstream = async_nats::jetstream::new(client);
     ///
@@ -191,7 +306,7 @@ impl Message {
     /// # async fn main() -> Result<(), async_nats::Error> {
     /// use async_nats::jetstream::consumer::PullConsumer;
     /// use async_nats::jetstream::AckKind;
-    /// use futures::StreamExt;
+    /// use futures_util::StreamExt;
     /// let client = async_nats::connect("localhost:4222").await?;
     /// let jetstream = async_nats::jetstream::new(client);
     ///
@@ -235,7 +350,7 @@ impl Message {
     /// ```no_run
     /// # #[tokio::main]
     /// # async fn main() -> Result<(), async_nats::Error> {
-    /// use futures::StreamExt;
+    /// use futures_util::StreamExt;
     /// let client = async_nats::connect("localhost:4222").await?;
     /// let jetstream = async_nats::jetstream::new(client);
     ///
@@ -422,7 +537,7 @@ impl Acker {
     /// # async fn main() -> Result<(), async_nats::Error> {
     /// use async_nats::jetstream::consumer::PullConsumer;
     /// use async_nats::jetstream::Message;
-    /// use futures::StreamExt;
+    /// use futures_util::StreamExt;
     /// let client = async_nats::connect("localhost:4222").await?;
     /// let jetstream = async_nats::jetstream::new(client);
     ///
@@ -469,7 +584,7 @@ impl Acker {
     /// use async_nats::jetstream::consumer::PullConsumer;
     /// use async_nats::jetstream::AckKind;
     /// use async_nats::jetstream::Message;
-    /// use futures::StreamExt;
+    /// use futures_util::StreamExt;
     /// let client = async_nats::connect("localhost:4222").await?;
     /// let jetstream = async_nats::jetstream::new(client);
     ///
@@ -519,7 +634,7 @@ impl Acker {
     /// # #[tokio::main]
     /// # async fn main() -> Result<(), async_nats::Error> {
     /// use async_nats::jetstream::Message;
-    /// use futures::StreamExt;
+    /// use futures_util::StreamExt;
     /// let client = async_nats::connect("localhost:4222").await?;
     /// let jetstream = async_nats::jetstream::new(client);
     ///
