@@ -39,7 +39,7 @@
 //!
 //! ```no_run
 //! use bytes::Bytes;
-//! use futures::StreamExt;
+//! use futures_util::StreamExt;
 //!
 //! #[tokio::main]
 //! async fn main() -> Result<(), async_nats::Error> {
@@ -98,7 +98,7 @@
 //!
 //! ```no_run
 //! # use bytes::Bytes;
-//! # use futures::StreamExt;
+//! # use futures_util::StreamExt;
 //! # use std::error::Error;
 //! # use std::time::Instant;
 //! # #[tokio::main]
@@ -192,11 +192,11 @@
 #![deny(rustdoc::private_intra_doc_links)]
 #![deny(rustdoc::invalid_codeblock_attributes)]
 #![deny(rustdoc::invalid_rust_codeblocks)]
-#![cfg_attr(docsrs, feature(doc_auto_cfg))]
+#![cfg_attr(docsrs, feature(doc_cfg))]
 
 use thiserror::Error;
 
-use futures::stream::Stream;
+use futures_util::stream::Stream;
 use tokio::io::AsyncWriteExt;
 use tokio::sync::oneshot;
 use tracing::{debug, error};
@@ -324,6 +324,15 @@ pub struct ServerInfo {
     /// Whether server goes into lame duck mode.
     #[serde(default, rename = "ldm")]
     pub lame_duck_mode: bool,
+    /// Name of the cluster if the server is in cluster-mode
+    #[serde(default)]
+    pub cluster: Option<String>,
+    /// The configured NATS domain of the server.
+    #[serde(default)]
+    pub domain: Option<String>,
+    /// Whether the server supports JetStream.
+    #[serde(default)]
+    pub jetstream: bool,
 }
 
 #[derive(Clone, Debug, Eq, PartialEq)]
@@ -345,19 +354,19 @@ pub(crate) enum ServerOp {
     },
 }
 
-/// `PublishMessage` represents a message being published
-#[derive(Debug)]
-pub struct PublishMessage {
-    pub subject: Subject,
-    pub payload: Bytes,
-    pub reply: Option<Subject>,
-    pub headers: Option<HeaderMap>,
-}
+/// An alias. This is done to avoid breaking changes
+/// in the public API. However this will get deprecated in the future in favor of
+/// [crate::message::OutboundMessage].
+#[deprecated(
+    since = "0.44.0",
+    note = "use `async_nats::message::OutboundMessage` instead"
+)]
+pub type PublishMessage = crate::message::OutboundMessage;
 
 /// `Command` represents all commands that a [`Client`] can handle
 #[derive(Debug)]
 pub(crate) enum Command {
-    Publish(PublishMessage),
+    Publish(OutboundMessage),
     Request {
         subject: Subject,
         payload: Bytes,
@@ -864,7 +873,7 @@ impl ConnectionHandler {
                     multiplexer
                 } else {
                     let prefix = Subject::from(format!("{}.{}.", prefix, nuid::next()));
-                    let subject = Subject::from(format!("{}*", prefix));
+                    let subject = Subject::from(format!("{prefix}*"));
 
                     self.connection.enqueue_write_op(&ClientOp::Subscribe {
                         sid: MULTIPLEXER_SID,
@@ -897,7 +906,7 @@ impl ConnectionHandler {
                 self.connection.enqueue_write_op(&pub_op);
             }
 
-            Command::Publish(PublishMessage {
+            Command::Publish(OutboundMessage {
                 subject,
                 payload,
                 reply: respond,
@@ -1221,7 +1230,7 @@ impl From<io::Error> for ConnectError {
 
 /// Retrieves messages from given `subscription` created by [Client::subscribe].
 ///
-/// Implements [futures::stream::Stream] for ergonomic async message processing.
+/// Implements [futures_util::stream::Stream] for ergonomic async message processing.
 ///
 /// # Examples
 /// ```
@@ -1283,7 +1292,7 @@ impl Subscriber {
     ///
     /// # Examples
     /// ```
-    /// # use futures::StreamExt;
+    /// # use futures_util::StreamExt;
     /// # #[tokio::main]
     /// # async fn main() -> Result<(), async_nats::Error> {
     /// let client = async_nats::connect("demo.nats.io").await?;
@@ -1318,7 +1327,7 @@ impl Subscriber {
     ///
     /// # Examples
     /// ```no_run
-    /// # use futures::StreamExt;
+    /// # use futures_util::StreamExt;
     /// # #[tokio::main]
     /// # async fn main() -> Result<(), async_nats::Error> {
     /// let client = async_nats::connect("demo.nats.io").await?;
@@ -1613,6 +1622,11 @@ impl ServerAddr {
         self.0.port_or_known_default().unwrap_or(4222)
     }
 
+    /// Returns the URL string.
+    pub fn as_url_str(&self) -> &str {
+        self.0.as_str()
+    }
+
     /// Returns the optional username in the url.
     pub fn username(&self) -> Option<&str> {
         let user = self.0.username();
@@ -1730,6 +1744,7 @@ macro_rules! from_with_timeout {
 pub(crate) use from_with_timeout;
 
 use crate::connection::ShouldFlush;
+use crate::message::OutboundMessage;
 
 #[cfg(test)]
 mod tests {
